@@ -2,7 +2,7 @@
  * Gnome Chemistry Utils
  * object.cc 
  *
- * Copyright (C) 2002-2005
+ * Copyright (C) 2002-2004
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -16,13 +16,12 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
- * USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA  02111-1307, USA.
  */
 
-#include "config.h"
 #include "object.h"
 #include "document.h"
 #include <string>
@@ -387,19 +386,19 @@ TypeId Object::AddType(string TypeName, Object*(*Create)(), TypeId id)
 		NextType = TypeId ((unsigned) NextType + 1);
 	} else
 		typedesc.Id = id;
-	if (TypeNames.size() <= typedesc.Id) {
-		size_t max = (((size_t) typedesc.Id / 10) + 1) * 10;
-		TypeNames.resize (max);
+	if (TypeNames.capacity() <=  typedesc.Id) {
+		size_t max = (((size_t)  typedesc.Id / 10) + 1) * 10;
+		TypeNames.reserve (max);
+		while (max > TypeNames.size())
+			TypeNames.push_back ("");
 	}
 #if HAS_VECTOR_AT
-	TypeNames.at (typedesc.Id) = TypeName;
+	TypeNames.at (id) = TypeName;
 #else
 	vector<string>::iterator it;
 	it = TypeNames.begin ();
 	it += typedesc.Id;
-	it = TypeNames.insert (it, TypeName);
-	it++;
-	TypeNames.erase (it);
+	TypeNames.insert (it, TypeName);
 #endif
 	return typedesc.Id;
 }
@@ -478,16 +477,16 @@ const set<TypeId>& Object::GetRules (const string& type, RuleId rule)
 	static set<TypeId> noId;
 	TypeDesc& typedesc = Types[type];
 	switch (rule) {
-		case RuleMustContain:
-			return typedesc.RequiredChildren;
-		case RuleMayContain:
-			return typedesc.PossibleChildren;
-		case RuleMustBeIn:
-			return typedesc.RequiredParents;
-		case RuleMayBeIn:
-			return typedesc.PossibleParents;
-		default:
-			return noId;
+	case RuleMustContain:
+		return typedesc.RequiredChildren;
+	case RuleMayContain:
+		return typedesc.PossibleChildren;
+	case RuleMustBeIn:
+		return typedesc.RequiredParents;
+	case RuleMayBeIn:
+		return typedesc.PossibleParents;
+	default:
+		return noId;
 	}
 	return noId;
 }
